@@ -1,5 +1,5 @@
 import shlex
-from ejcli.http import task_list, task_ids, clars, submit_clar, read_clar
+from ejcli.http import tasks, clar_list, submit_clar, read_clar
 
 def do_clars(self, cmd):
     """
@@ -22,17 +22,15 @@ def do_clars(self, cmd):
     elif cmd[0] == 'list':
         if len(cmd) != 1: return self.do_help('clars')
         print('Clar ID\tSubject')
-        for k, v in zip(*clars(self.url, self.cookie)):
+        for k, v in clar_list(self.url, self.cookie):
             print('%d\t%s'%(k, v))
     elif cmd[0] == 'read':
         if len(cmd) != 2 or not cmd[1].strip().isnumeric(): return self.do_help('clars')
         print(read_clar(self.url, self.cookie, int(cmd[1])))
     elif cmd[0] == 'send':
         if len(cmd) != 3: return self.do_help('clars')
-        tl = task_list(self.url, self.cookie)
-        ti = task_ids(self.url, self.cookie)
-        try: task = ti[tl.index(cmd[1])]
-        except (ValueError, IndexError):
+        try: task = next(i.id for i in tasks(self.url, self.cookie) if i.short_name == cmd[1])
+        except StopIteration:
             raise EJError("No such task")
         data = ''
         while not data.endswith('\n\n'):
