@@ -1,9 +1,9 @@
-import ejcli._http.ejudge, ejcli._http.ejudge.ejfuse, ejcli._http.pcms, ejcli._http.jjs, ejcli._http.informatics, ejcli._http.codeforces, ejcli._http.gcj, ejcli._http.cache, urllib.request
+import ejcli._http.ejudge, ejcli._http.ejudge.ejfuse, ejcli._http.pcms, ejcli._http.jjs, ejcli._http.informatics, ejcli._http.codeforces, ejcli._http.gcj, ejcli._http.cache, ejcli._http.file, urllib.request
 from ejcli._http.ejudge import contest_name
 from ejcli.error import EJError
 from ejcli._http.types import *
 
-backend_path = [ejcli._http.cache.AggressiveCacheBackend, ejcli._http.ejudge.ejfuse.EJFuse, ejcli._http.jjs.JJS, ejcli._http.informatics.Informatics, ejcli._http.codeforces.CodeForces, ejcli._http.gcj.GCJ, ejcli._http.pcms.PCMS, ejcli._http.ejudge.Ejudge]
+backend_path = [ejcli._http.cache.AggressiveCacheBackend, ejcli._http.file.FileBackend, ejcli._http.ejudge.ejfuse.EJFuse, ejcli._http.jjs.JJS, ejcli._http.informatics.Informatics, ejcli._http.codeforces.CodeForces, ejcli._http.gcj.GCJ, ejcli._http.pcms.PCMS, ejcli._http.ejudge.Ejudge]
 
 def login(url, login, password, **kwds):
     for i in backend_path:
@@ -25,7 +25,7 @@ def _create_wrapper(name):
         return getattr(args[0], name)(*args[2:], **kwds)
     globals()[name] = func
 
-for _w in ['tasks', 'submissions', 'submission_protocol', 'task_ids', 'submit_solution', 'status', 'scores', 'compile_error', 'submission_source', 'do_action', 'compiler_list', 'submission_stats', 'contest_info', 'problem_info', 'download_file', 'clar_list', 'submit_clar', 'read_clar', 'get_samples', 'may_cache', 'scoreboard', 'change_password']:
+for _w in ['tasks', 'submissions', 'submission_protocol', 'task_ids', 'submit_solution', 'status', 'scores', 'compile_error', 'submission_source', 'do_action', 'compiler_list', 'submission_stats', 'contest_info', 'problem_info', 'download_file', 'clar_list', 'submit_clar', 'read_clar', 'get_samples', 'may_cache', 'scoreboard', 'change_password', 'locales', 'set_locale']:
     _create_wrapper(_w)
 
 del _create_wrapper, _w
